@@ -52,11 +52,11 @@ class KateDocumentInfo
     unsigned char modifiedOnDiscReason;
 };
 
-typedef QPair<KURL,TQDateTime> TPair;
+typedef TQPair<KURL,TQDateTime> TPair;
 
 class KateDocManager : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
 
   public:
     KateDocManager (TQObject *parent);
