@@ -30,9 +30,9 @@ class TDEProcess;
 
 namespace KHC {
 
-class IndexBuilder : public QObject
+class IndexBuilder : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   public:
     IndexBuilder(const TQString& cmdFile);
 
