@@ -197,7 +197,7 @@ bool Workspace::workspaceEvent( XEvent * e )
     if ( mouse_emulation && (e->type == ButtonPress || e->type == ButtonRelease ) )
         {
         mouse_emulation = FALSE;
-        XUngrabKeyboard( tqt_xdisplay(), GET_QT_X_TIME() );
+        XUngrabKeyboard( tqt_xdisplay(), get_tqt_x_time() );
         }
 
     if( e->type == PropertyNotify || e->type == ClientMessage )
@@ -292,11 +292,11 @@ bool Workspace::workspaceEvent( XEvent * e )
                  !e->xcreatewindow.override_redirect )
             {
         // see comments for allowClientActivation()
-            Time my_qtx_time = GET_QT_X_TIME();
+            Time my_qtx_time = get_tqt_x_time();
             XChangeProperty(tqt_xdisplay(), e->xcreatewindow.window,
                             atoms->kde_net_wm_user_creation_time, XA_CARDINAL,
                             32, PropModeReplace, (unsigned char *)&my_qtx_time, 1);
-            SET_QT_X_TIME(my_qtx_time);
+            set_tqt_x_time(my_qtx_time);
             }
         break;
 
@@ -785,8 +785,13 @@ void Client::configureRequestEvent( XConfigureRequestEvent* e )
     {
     if( e->window != window())
         return; // ignore frame/wrapper
-    if ( isResize() || isMove())
+    if ( isResize() || isMove() || inhibitConfigureRequests)
+        {
+        // Send a synthetic configure notification to make sure the
+        // window contents get updated by the application
+        sendSyntheticConfigureNotify();
         return; // we have better things to do right now
+        }
 
     if( fullscreen_mode == FullScreenNormal ) // refuse resizing of fullscreen windows
         { // but allow resizing fullscreen hacks in order to let them cancel fullscreen mode
@@ -818,7 +823,7 @@ void Client::configureRequestEvent( XConfigureRequestEvent* e )
         restackWindow( e->above, e->detail, NET::FromApplication, userTime(), false );
 
     // TODO sending a synthetic configure notify always is fine, even in cases where
-    // the ICCCM doesn't require this - it can be though of as 'the WM decided to move
+    // the ICCCM doesn't require this - it can be thought of as 'the WM decided to move
     // the window later'. The client should not cause that many configure request,
     // so this should not have any significant impact. With user moving/resizing
     // the it should be optimized though (see also Client::setGeometry()/plainResize()/move()).
@@ -881,7 +886,7 @@ void Client::enterNotifyEvent( XCrossingEvent* e )
             {
             delete shadeHoverTimer;
             shadeHoverTimer = new TQTimer( this );
-            connect( shadeHoverTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( shadeHover() ));
+            connect( shadeHoverTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( shadeHover() ));
             shadeHoverTimer->start( options->shadeHoverInterval, TRUE );
             }
 
@@ -894,7 +899,7 @@ void Client::enterNotifyEvent( XCrossingEvent* e )
             {
             delete autoRaiseTimer;
             autoRaiseTimer = new TQTimer( this );
-            connect( autoRaiseTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( autoRaise() ) );
+            connect( autoRaiseTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( autoRaise() ) );
             autoRaiseTimer->start( options->autoRaiseInterval, TRUE  );
             }
 
@@ -924,7 +929,7 @@ void Client::leaveNotifyEvent( XCrossingEvent* e )
         if ( !buttonDown )
             {
             mode = PositionCenter;
-            setCursor( tqarrowCursor );
+            setCursor( TQt::arrowCursor );
             }
         bool lostMouse = !rect().contains( TQPoint( e->x, e->y ) );
         // 'lostMouse' wouldn't work with e.g. B2 or Keramik, which have non-rectangular decorations
@@ -1295,25 +1300,25 @@ bool Client::eventFilter( TQObject* o, TQEvent* e )
         return false;
     if( e->type() == TQEvent::MouseButtonPress )
         {
-        TQMouseEvent* ev = TQT_TQMOUSEEVENT( e );
+        TQMouseEvent* ev = static_cast<TQMouseEvent*>( e );
         return buttonPressEvent( decorationId(), qtToX11Button( ev->button()), qtToX11State( ev->state()),
             ev->x(), ev->y(), ev->globalX(), ev->globalY() );
         }
     if( e->type() == TQEvent::MouseButtonRelease )
         {
-        TQMouseEvent* ev = TQT_TQMOUSEEVENT( e );
+        TQMouseEvent* ev = static_cast<TQMouseEvent*>( e );
         return buttonReleaseEvent( decorationId(), qtToX11Button( ev->button()), qtToX11State( ev->state()),
             ev->x(), ev->y(), ev->globalX(), ev->globalY() );
         }
     if( e->type() == TQEvent::MouseMove ) // FRAME i fake z enter/leave?
         {
-        TQMouseEvent* ev = TQT_TQMOUSEEVENT( e );
+        TQMouseEvent* ev = static_cast<TQMouseEvent*>( e );
         return motionNotifyEvent( decorationId(), qtToX11State( ev->state()),
             ev->x(), ev->y(), ev->globalX(), ev->globalY() );
         }
     if( e->type() == TQEvent::Wheel )
         {
-        TQWheelEvent* ev = TQT_TQWHEELEVENT( e );
+        TQWheelEvent* ev = static_cast<TQWheelEvent*>( e );
         bool r = buttonPressEvent( decorationId(), ev->delta() > 0 ? Button4 : Button5, qtToX11State( ev->state()),
             ev->x(), ev->y(), ev->globalX(), ev->globalY() );
         r = r || buttonReleaseEvent( decorationId(), ev->delta() > 0 ? Button4 : Button5, qtToX11State( ev->state()),
@@ -1322,7 +1327,7 @@ bool Client::eventFilter( TQObject* o, TQEvent* e )
         }
     if( e->type() == TQEvent::Resize )
         {
-        TQResizeEvent* ev = TQT_TQRESIZEEVENT( e );
+        TQResizeEvent* ev = static_cast<TQResizeEvent*>( e );
         // Filter out resize events that inform about size different than frame size.
         // This will ensure that decoration->width() etc. and decoration->widget()->width() will be in sync.
         // These events only seem to be delayed events from initial resizing before show() was called
@@ -1550,7 +1555,7 @@ static bool waitingMotionEvent()
 // of processes events reaches the timestamp of the last suitable
 // MotionNotify event in the queue.
     if( next_motion_time != CurrentTime
-        && timestampCompare( GET_QT_X_TIME(), next_motion_time ) < 0 )
+        && timestampCompare( get_tqt_x_time(), next_motion_time ) < 0 )
         return true;
     was_motion = false;
     XSync( tqt_xdisplay(), False ); // this helps to discard more MotionNotify events
