@@ -204,8 +204,13 @@ class Workspace : public TQObject, public KWinInterface, public KDecorationDefin
         void windowToNextDesktop( Client* c );
         void sendClientToScreen( Client* c, int screen );
 
-    // KDE4 remove me - and it's also in the DCOP interface :(
         void showWindowMenuAt( unsigned long id, int x, int y );
+        void showWindowMenu( unsigned long id );
+
+        void tileWindowToBorder(unsigned long w1, int location);
+        void tileTwoWindowsHorizontally(unsigned long w1, unsigned long w2);
+        void tileTwoWindowsVertically(unsigned long w1, unsigned long w2);
+        void tileFourWindowsInGrid(unsigned long w1, unsigned long w2, unsigned long w3, unsigned long w4);
         void kDestopResized();
 
         /**
@@ -410,6 +415,7 @@ class Workspace : public TQObject, public KWinInterface, public KDecorationDefin
         void writeWindowRules();
         void kipcMessage( int id, int data );
         void updateActiveBorders();
+        void tileCurrentWindowToBorder(int position);
         // kompmgr
         void setPopupClientOpacity(int v);
         void resetClientOpacity();
@@ -501,6 +507,7 @@ class Workspace : public TQObject, public KWinInterface, public KDecorationDefin
 
         void calcDesktopLayout(int &x, int &y) const;
 
+        TQPopupMenu* makeTileMenu();
         TQPopupMenu* clientPopup();
         void closeActivePopup();
 
@@ -585,6 +592,7 @@ class Workspace : public TQObject, public KWinInterface, public KDecorationDefin
         TQPopupMenu *advanced_popup;
         TQPopupMenu *desk_popup;
         int desk_popup_index;
+        int tile_popup_index;
 
         TDEGlobalAccel *keys;
         TDEGlobalAccel *client_keys;
